==> flutter_firebase_basic_tools-0.0.20.tar.gz: lib/widgets/princing_container.dart <==
import 'package:flutter_firebase_basic_tools/widgets/pricing_container_item.dart';
import 'package:flutter_firebase_basic_tools/screens/payment_webview.dart';
import 'package:flutter/material.dart';

class PricingContainer extends StatefulWidget {
  const PricingContainer({
    @required this.texts,
    @required this.userID,
    @required this.customerEmail,
  });

  final List<String> texts;
  final String userID;
  final String customerEmail;

  @override
  _PricingContainerState createState() => _PricingContainerState();
}

class _PricingContainerState extends State<PricingContainer> {
  double currentPage = 0;
  final PageController pageController = PageController(initialPage: 0);

  List<Map<String, dynamic>> priceIDList = [
    {
      "name": "White Belt",
      //"id": "sku_HIvmKnNdqFdcKs", // TEST
      "id": "sku_HMZSl1wuFpKPRh", // PROD
      "course_id": "njrXMgGFkJklI3ZZONSP",
    },
    {
      "name": "Yellow Belt",
      //"id": "sku_HIvjT9AY7rsBga", // TEST
      "id": "sku_HMZQ1Av6Wbbfbs", // PROD
      "course_id": "njrXMgGFkJklI3ZZONSP",
    },
    {
      "name": "Black Belt",
      //"id": "sku_HIvi1IGIJ2JupX", // TEST
      "id": "sku_HMZQ1Av6Wbbfbs", // PROD
      "course_id": "njrXMgGFkJklI3ZZONSP",
    },
    {
      "name": "Leadership & Development",
      //"id": "sku_HIvi1IGIJ2JupX", // TEST
      "id": "sku_HMZRBPi2Jma91v", // PROD
      "course_id": "njrXMgGFkJklI3ZZONSP",
    },
    {
      "name": "Fundamentos del Plan de Continuidad del Negocio",
      //"id": "sku_HIvnpHLrRPowP0", // TEST
      "id": "sku_HMZRVoUcSccaqE", // PROD
      "course_id": "njrXMgGFkJklI3ZZONSP",
    },
  ];

  navigateToPaymentWebview1() {
    Navigator.pushNamed(
      context,
      "/ /buy_courses/payment_webview",
      arguments: StripePayment(
        priceID: priceIDList[0]["id"],
        userID: widget.userID,
        customerEmail: widget.customerEmail,
        courseID: priceIDList[0]["course_id"],
      ),
    );
  }

  navigateToPaymentWebview2() {
    Navigator.pushNamed(
      context,
      "/ /buy_courses/payment_webview",
      arguments: StripePayment(
        priceID: priceIDList[1]["id"],
        userID: widget.userID,
        customerEmail: widget.customerEmail,
        courseID: priceIDList[1]["course_id"],
      ),
    );
  }

  navigateToPaymentWebview3() {
    Navigator.pushNamed(
      context,
      "/ /buy_courses/payment_webview",
      arguments: StripePayment(
        priceID: priceIDList[2]["id"],
        userID: widget.userID,
        customerEmail: widget.customerEmail,
        courseID: priceIDList[2]["course_id"],
      ),
    );
  }

  navigateToPaymentWebview4() {
    Navigator.pushNamed(
      context,
      "/ /buy_courses/payment_webview",
      arguments: StripePayment(
        priceID: priceIDList[3]["id"],
        userID: widget.userID,
        customerEmail: widget.customerEmail,
        courseID: priceIDList[3]["course_id"],
      ),
    );
  }

  @override
  Widget build(BuildContext context) {
    bool isPortrait =
        MediaQuery.of(context).size.width > MediaQuery.of(context).size.height
            ? false
            : true;

    return Container(
      color: Colors.blue.shade800,
      height: isPortrait
          ? (MediaQuery.of(context).size.height * 3.2)
          : (MediaQuery.of(context).size.height),
      width: MediaQuery.of(context).size.width,
      child: Column(
        children: <Widget>[
          Spacer(flex: 1),
          Expanded(
            flex: isPortrait ? 3 : 1,
            child: FractionallySizedBox(
              widthFactor: 0.7,
              child: Text(
                widget.texts[0],
                textAlign: TextAlign.center,
                style: TextStyle(
                  color: Colors.white,
                  fontSize: 40,
                  //fontWeight: FontWeight.bold,
                ),
              ),
            ),
          ),
          Expanded(
            flex: isPortrait ? 2 : 1,
            child: FractionallySizedBox(
              widthFactor: 0.7,
              child: Text(
                widget.texts[1],
                textAlign: TextAlign.center,
                style: TextStyle(
                  color: Colors.white,
                  fontSize: 18,
                ),
              ),
            ),
          ),
          Expanded(
            flex: isPortrait ? 42 : 12,
            child: FractionallySizedBox(
              widthFactor: 0.8,
              child: Flex(
                direction: isPortrait ? Axis.vertical : Axis.horizontal,
                children: <Widget>[
                  Expanded(
                    flex: 10,
                    child: PricingContainerItem(
                      //title: widget.texts[2],
                      title: "White Belt",
                      description: widget.texts[3],
                      characteristics: ' ',
                      icon: Icons.shutter_speed,
                      color: Colors.white,
                      imageUrl: 'assets/images/student_1.jpg',

                      gradientColor1:
                          Colors.blueGrey.shade200.withOpacity(0.25),
                      gradientColor2:
                          Colors.blueGrey.shade700.withOpacity(0.75),
                      comingSoon: true,
                      function: navigateToPaymentWebview1,
                    ),
                  ),
                  isPortrait ? Container() : Spacer(flex: 1),
                  Expanded(
                    flex: 10,
                    child: PricingContainerItem(
                      //title: widget.texts[4],
                      title: "Yellow Belt",
                      description: widget.texts[5],
                      characteristics: ' ',
                      icon: Icons.message,
                      color: Colors.white,
                      imageUrl: 'assets/images/student_2.jpg',
                      gradientColor1:
                          Colors.orangeAccent.shade200.withOpacity(0.25),
                      gradientColor2:
                          Colors.orangeAccent.shade700.withOpacity(0.75),
                      comingSoon: false,
                      function: navigateToPaymentWebview2,
                    ),
                  ),
                  isPortrait ? Container() : Spacer(flex: 1),
                  Expanded(
                    flex: 10,
                    child: PricingContainerItem(
                      //title: widget.texts[6],
                      title: "Black Belt",
                      description: widget.texts[7],
                      characteristics: ' ',
                      icon: Icons.compare,
                      color: Colors.white,
                      imageUrl: 'assets/images/family.jpg',
                      gradientColor1: Colors.grey.shade700.withOpacity(0.25),
                      gradientColor2: Colors.grey.shade900.withOpacity(0.75),
                      comingSoon: true,
                      function: navigateToPaymentWebview3,
                    ),
                  ),
                ],
              ),
            ),
          ),
        ],
      ),
    );
  }
}

==> flutter_firebase_basic_tools-0.0.120.tar.gz: lib/widgets/princing_container.dart <==
import 'package:flutter_firebase_basic_tools/widgets/pricing_container_item.dart';
import 'package:flutter_firebase_basic_tools/screens/payment_webview.dart';
import 'package:flutter/material.dart';

class PricingContainer extends StatefulWidget {
  const PricingContainer({
    @required this.texts,
    @required this.userID,
    @required this.customerEmail,
    @required this.backgroundColor,
    @required this.titleColor,
    @required this.subtitleColor,
    @required this.image1,
    @required this.image2,
    @required this.image3,
  });

  final List<String> texts;
  final String userID;
  final String customerEmail;
  final Color backgroundColor;
  final Color titleColor;
  final Color subtitleColor;
  final String image1;
  final String image2;
  final String image3;

  @override
  _PricingContainerState createState() => _PricingContainerState();
}

class _PricingContainerState extends State<PricingContainer> {
  double currentPage = 0;
  final PageController pageController = PageController(initialPage: 0);

  List<Map<String, dynamic>> priceIDList = [
    {
      "name": "White Belt",
      //"id": "sku_HIvmKnNdqFdcKs", // TEST
      "id": "sku_HMZSl1wuFpKPRh", // PROD
      "course_id": "njrXMgGFkJklI3ZZONSP",
    },
    {
      "name": "Yellow Belt",
      //"id": "sku_HIvjT9AY7rsBga", // TEST
      "id": "sku_HMZQ1Av6Wbbfbs", // PROD
      "course_id": "njrXMgGFkJklI3ZZONSP",
    },
    {
      "name": "Black Belt",
      //"id": "sku_HIvi1IGIJ2JupX", // TEST
      "id": "sku_HMZQ1Av6Wbbfbs", // PROD
      "course_id": "njrXMgGFkJklI3ZZONSP",
    },
    {
      "name": "Leadership & Development",
      //"id": "sku_HIvi1IGIJ2JupX", // TEST
      "id": "sku_HMZRBPi2Jma91v", // PROD
      "course_id": "njrXMgGFkJklI3ZZONSP",
    },
    {
      "name": "Fundamentos del Plan de Continuidad del Negocio",
      //"id": "sku_HIvnpHLrRPowP0", // TEST
      "id": "sku_HMZRVoUcSccaqE", // PROD
      "course_id": "njrXMgGFkJklI3ZZONSP",
    },
  ];

  navigateToPaymentWebview1() {
    Navigator.pushNamed(
      context,
      "/ /buy_courses/payment_webview",
      arguments: StripePayment(
        priceID: priceIDList[0]["id"],
        userID: widget.userID,
        customerEmail: widget.customerEmail,
        courseID: priceIDList[0]["course_id"],
      ),
    );
  }

  navigateToPaymentWebview2() {
    Navigator.pushNamed(
      context,
      "/ /buy_courses/payment_webview",
      arguments: StripePayment(
        priceID: priceIDList[1]["id"],
        userID: widget.userID,
        customerEmail: widget.customerEmail,
        courseID: priceIDList[1]["course_id"],
      ),
    );
  }

  navigateToPaymentWebview3() {
    Navigator.pushNamed(
      context,
      "/ /buy_courses/payment_webview",
      arguments: StripePayment(
        priceID: priceIDList[2]["id"],
        userID: widget.userID,
        customerEmail: widget.customerEmail,
        courseID: priceIDList[2]["course_id"],
      ),
    );
  }

  navigateToPaymentWebview4() {
    Navigator.pushNamed(
      context,
      "/ /buy_courses/payment_webview",
      arguments: StripePayment(
        priceID: priceIDList[3]["id"],
        userID: widget.userID,
        customerEmail: widget.customerEmail,
        courseID: priceIDList[3]["course_id"],
      ),
    );
  }

  @override
  Widget build(BuildContext context) {
    bool isPortrait =
        MediaQuery.of(context).size.width > MediaQuery.of(context).size.height
            ? false
            : true;

    return Container(
      color: widget.backgroundColor,
      height: isPortrait
          ? (MediaQuery.of(context).size.height * 3.2)
          : (MediaQuery.of(context).size.height),
      width: MediaQuery.of(context).size.width,
      child: Column(
        children: <Widget>[
          Spacer(flex: 1),
          Expanded(
            flex: isPortrait ? 3 : 1,
            child: FractionallySizedBox(
              widthFactor: 0.7,
              child: Text(
                widget.texts[0],
                textAlign: TextAlign.center,
                style: TextStyle(
                  color: widget.titleColor,
                  fontSize: 40,
                  //fontWeight: FontWeight.bold,
                ),
              ),
            ),
          ),
          Expanded(
            flex: isPortrait ? 2 : 1,
            child: FractionallySizedBox(
              widthFactor: 0.7,
              child: Text(
                widget.texts[1],
                textAlign: TextAlign.center,
                style: TextStyle(
                  color: widget.subtitleColor,
                  fontSize: 18,
                ),
              ),
            ),
          ),
          Expanded(
            flex: isPortrait ? 42 : 12,
            child: FractionallySizedBox(
              widthFactor: 0.8,
              child: Flex(
                direction: isPortrait ? Axis.vertical : Axis.horizontal,
                children: <Widget>[
                  Expanded(
                    flex: 10,
                    child: PricingContainerItem(
                      //title: widget.texts[2],
                      title: "White Belt",
                      description: widget.texts[3],
                      characteristics: ' ',
                      icon: Icons.shutter_speed,
                      textColor: Colors.white,
                      imageUrl: widget.image1,
                      gradientColor1:
                          Colors.blueGrey.shade200.withOpacity(0.25),
                      gradientColor2:
                          Colors.blueGrey.shade700.withOpacity(0.75),
                      comingSoon: true,
                      function: navigateToPaymentWebview1,
                    ),
                  ),
                  isPortrait ? Container() : Spacer(flex: 1),
                  Expanded(
                    flex: 10,
                    child: PricingContainerItem(
                      //title: widget.texts[4],
                      title: "Yellow Belt",
                      description: widget.texts[5],
                      characteristics: ' ',
                      icon: Icons.message,
                      textColor: Colors.white,
                      imageUrl: widget.image2,
                      gradientColor1:
                          Colors.orangeAccent.shade200.withOpacity(0.25),
                      gradientColor2:
                          Colors.orangeAccent.shade700.withOpacity(0.75),
                      comingSoon: false,
                      function: navigateToPaymentWebview2,
                    ),
                  ),
                  isPortrait ? Container() : Spacer(flex: 1),
                  Expanded(
                    flex: 10,
                    child: PricingContainerItem(
                      //title: widget.texts[6],
                      title: "Black Belt",
                      description: widget.texts[7],
                      characteristics: ' ',
                      icon: Icons.compare,
                      textColor: Colors.white,
                      imageUrl: widget.image3,
                      gradientColor1: Colors.grey.shade700.withOpacity(0.25),
                      gradientColor2: Colors.grey.shade900.withOpacity(0.75),
                      comingSoon: true,
                      function: navigateToPaymentWebview3,
                    ),
                  ),
                ],
              ),
            ),
          ),
        ],
      ),
    );
  }
}
